@@ -92,11 +92,13 @@ class ConvParser(Parser):
             d = {}
             # IMPORTANT: If any of the input loops require padding, they should be defined as the rightmost dimensions in the equation
             # This is because we construct the dimensionality order and then add the padding to those last dimensions in the order
-            d["equation"] = 'O[b][g][k][oy][ox]+=W[k][c][fy][fx]*I[b][g][c][iy][ix]'
+            d["equation"] = 'O[b][g][k][oy][ox]+=W[g][k][c][fy][fx]*I[b][g][c][iy][ix]'
 
             # Get dimension sizes from input parameters
             assert ia_shape[0] == oa_shape[0], "Batch size is different for input and output activations."
             B = oa_shape[0]
+            if B == 0:
+                B = 1
             G = groups
             K = ceil(oa_shape[1]/G)
             OX = oa_shape[2]
@@ -107,6 +109,7 @@ class ConvParser(Parser):
             FX = kernel_shape[0]
             FY = kernel_shape[1]
             d["loop_dim_size"] = {'B': B, 'K': K, 'G': G, "OX": OX, "OY": OY, "C": C, "FX": FX, "FY": FY}
+            d["pr_loop_dim_size"] = {'IX': IX, 'IY': IY}
             d["dimension_relations"] = [f'ix={strides[0]}*ox+{dilations[0]}*fx', f'iy={strides[1]}*oy+{dilations[1]}*fy']
             d["operand_precision"] =  {'O': 16, 'O_final': 8, 'W': 8, 'I': 8}
             # d["operand_source"] =  {'W': [], 'I': []}
@@ -114,6 +117,7 @@ class ConvParser(Parser):
 
             d["core_allocation"] =  node_mapping["core_allocation"]
             d["spatial_mapping"] =  node_mapping["spatial_mapping"]
+            d["temporal_ordering"] = node_mapping.get("temporal_ordering", None)
             d["memory_operand_links"] =  node_mapping["memory_operand_links"]
 
             # Find the previous layer(s) that should be this node's parent(s)
